globals
[
  tick-counter
  total-stock-camps
  total-people
  initial-total-people
  fraction-death
  total-monitor-cost-of-monitoring-organizations
  total-humorgs-cost-of-humorgs
  ;monsoon
]


breed [people person]
breed [monitors monitor]
breed [humorgs humorg]
breed [camps camp]

people-own [
  health-level
  max-health-level
  health-threshold
  camp-belong
  needs-per-day

]

camps-own [
  camp-capacity
  stock
  population-camp-count
  needs-camp-count

]

monitors-own [
  monitor-cost
  total-monitor-cost
  monitor-time-cycle
  monitor-duration
  population-monitor
  needs-monitor
  report-tick
  monitor-area-coordination-given-similar-actual-monitoring-cycle?
  still-monitor
  still-monitor?
  area-division-monitor?
]

humorgs-own [
  humorgs-cost-average
  humorgs-distribution-time
  logistic-sent
  needs-covered
  total-humorgs-cost
  distribute-tick
  ;update-distribution-time?
]

to setup
  clear-all
  setup-globals
  setup-camps
  setup-people
  setup-monitors
  setup-humorgs
  reset-ticks
end

to setup-globals
  set tick-counter -1 ; so the monitoring can start from zero tick, hence avoiding bias from late monitoring at the beginning of model run.
  set initial-total-people (average-people-per-camp * total-camps) ; assuming population growth is zero during three months of cyclone. approximate total number of pop for the three camps is 98k people
  set total-people 0
  ;set total-stock-camps sum stock
end


to setup-camps
  create-camps total-camps ; use slider
  ask camps [
    setxy (min-pxcor + 1) (random-float -25 + 12)
    set shape "campsite"
    set size 3
    Set color violet - 2 + random 5

    set camp-capacity random-normal initial-camp-capacity 5 ; use slider 'initial-camp-capacity' in interface, assume 100
    set stock camp-capacity ; assuming full stock available at the beginning
    set population-camp-count 0
    set needs-camp-count 0
  ]

end

to setup-people
  create-people  (average-people-per-camp * total-camps)  ; assuming population growth is zero during three months of cyclone. approximate total number of pop for the three camps is 98k people
  ask people [
    setxy random-float -25 + 13 random-float -25 + 12
    set shape "person"
    set size 1
    set color white - 2 + random 5
    set health-level  base-health  ;use slider 'base-health',  assume 80 (max level is 100)
    set health-threshold base-death-threshold


    Set camp-belong one-of camps
    set max-health-level 100
    set needs-per-day random-normal (max-health-level - health-level) deviation-needs-per-day ; (base-needs-people-per-day * (100 / (100 - (health-level)))) 0.3
   ; set needs-per-day random-normal (base-needs-people-per-day * (100 / (100 - (health-level)))) deviation-needs-per-day
  ]

end

to setup-monitors
  create-monitors number-of-monitoring-organization ; use slider 'number-of-monitoring-organization', assume 5
  ask monitors
  [
    set color yellow - 2 + random 5
    set shape "pentagon"
    set size 3
    setxy (random-float -25 + 12) (max-pycor - 1)

    set monitor-cost average-monitor-cost ; use slider 'average-monitor-cost', assume 100 (Euro)
    set total-monitor-cost 0

   if-else number-of-monitoring-organization > 1 ; 1 means centralized, else decentralized monitoring
    [

      if-else not similar-plan-monitoring-cycle?
      [
        set monitor-time-cycle  random-poisson average-monitor-time-cycle ; average-monitor-time-cycle
;      if-else similar-plan-monitoring-cycle? [set monitor-time-cycle average-monitor-time-cycle] [set monitor-time-cycle random-poisson average-monitor-time-cycle] ;deviation-monitor-time-cycle
;      ; the lower average-monitor-time-cycle, more frequent assessment is done.
      ]
      [
        if-else coordination-type-when-similar-monitoring-plan-ON = "area" ; else means "schedule"
        [
          set monitor-time-cycle  random-poisson average-monitor-time-cycle
        ]
        [
          check-monitoring-cycle
        ]
      ]
    ]
    [
      set monitor-time-cycle average-monitor-time-cycle
    ]

    set population-monitor 0
    set report-tick 0
    set monitor-area-coordination-given-similar-actual-monitoring-cycle? False

  ]
end

to setup-humorgs
  create-humorgs 1 ; assume 1 for simplification.
                   ; because we focus more on monitoring cycle plan, and creating > 1 humorgs requires additional mechanism identifying structure for plausible coordination

  ask humorgs
    [
      set shape "building institution"
      set color red
      set size 3
      setxy (random-float -25 + 12) (min-pycor + 1)
      set humorgs-cost-average 0
      ;set humorgs-distribution-time random-normal logistic-distribution-time deviation-logistic-distribution-time
      set logistic-sent 0
      set needs-covered 0
      set total-humorgs-cost 0
      set distribute-tick 0
      ;set update-distribution-time? False
  ]
end


to go

;  grow-people-in-number ; when population influx is integrated, assessing monitoring effectiveness in terms of people alive or casualties number
                         ; can be biased due to the increase of population. Better monitoring indicator for the model when grow-people-in-number is active is then required.

  ask people
  [
    ;update-camp-belong
    move
    update-health-level-monsoon
    consume-logistic
    update-life
  ]

  ask monitors
  [
    if monitor-time-cycle = 0
        [set monitor-time-cycle average-monitor-time-cycle]

    if-else number-of-monitoring-organization > 1
    [
      if-else similar-plan-monitoring-cycle?
        [

          if coordination-type-when-similar-monitoring-plan-ON = "area"
          [
            set monitor-area-coordination-given-similar-actual-monitoring-cycle? True ; coordination of area
            monitor-procedure ; given there is similar cycle plan, hence procedure is started after coordination finishes
          ]

          if coordination-type-when-similar-monitoring-plan-ON = "schedule"
          [
            set monitor-area-coordination-given-similar-actual-monitoring-cycle? False ;
            if not still-monitor?  ; coordination of schedule
            [
              monitor-procedure
            ]
          ]
        ]
        [
          monitor-procedure ; given there is similar cycle plan, hence procedure is started after coordination finishes
        ]
    ]
    [
      monitor-procedure ; given only 1 monitor in system
    ]

  ]

;  ask humorgs
;  [
;    if update-distribution-time?
;    [
;      update-distribution
;    ]
;  ]


  ;; ensuring model stops at 3 months / 90 days
  Set tick-counter (tick-counter + 1)
  if-else tick-counter <= tick-counter-limit
  [ Tick ]
  [ stop ]

  ;; plotting the results that are needed
  plot-results
  update-stats

  if total-people = 0
  [stop]

end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;people and camps;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;to update-camp-belong
;  if monsoon-effect > 1
;  [ MAKE LINK BETWEEN CAMPS AND PEOPLE, MAKE LINKS CHANGED EVERYTIME MONSOON HAPPENS.

;end

;to grow-people-in-number
;  if tick-counter > 0 and tick-counter mod random-poisson average-influx-cycle = 0
;  [
;    create-people random-poisson average-people-influx-rate-per-event-tick ; assuming population growth is zero during three months of cyclone. approximate total number of pop for the three camps is 98k people
;    ask people
;    [
;    setxy random-float -25 + 13 random-float -25 + 12
;    set shape "person"
;    set size 1
;    set color white - 2 + random 5
;    set health-level random-normal base-health 5 ;use slider 'base-health',  assume 80 (max level is 100)
;    set health-threshold random-normal base-death-threshold 0.5 ;use slider 'base-death-threshold', assume 5
;
;
;    Set camp-belong one-of camps
;    set max-health-level 100
;    set needs-per-day random-normal (max-health-level - health-level) deviation-needs-per-day ; (base-needs-people-per-day * (100 / (100 - (health-level)))) 0.3
;    ]
;  ]
;
;end

to move
  rt random 360
  fd 0.1
end

to update-health-level-monsoon
  if random-float monsoon-effect-slider > 0
  [
    set health-level max list (health-level - random-float  monsoon-effect-slider) 0  ; assuming that monsoon-effect also embodies supply-lack-effect, no randomness to generate deterministic insight here
  ]

end


to update-life
  if health-level < health-threshold [die]
end

to consume-logistic

  if health-level < 100
  [
    ask camps
    [
    ;let stock-camps [stock] of camp-belong
      set population-camp-count count people with [camp-belong = myself]
      if population-camp-count > 0
      [

        let needs-per-day-per-camp (sum [needs-per-day] of people with [camp-belong = myself])
        if-else stock >= needs-per-day-per-camp
        [
          ask people with [camp-belong = myself]
          [
           set health-level (health-level + needs-per-day )
          ]
        ]
        [
          let knowledge-stock-per-camp stock
          let knowledge-population-camp-count population-camp-count
          ask people with [camp-belong = myself]
          [
            improve-health-level knowledge-stock-per-camp knowledge-population-camp-count
            ;improve-health-level knowledge-population-camp-count
          ]
        ]
     ]
     update-stock
   ]
  ]
end

to improve-health-level [knowledge-stock-per-camp knowledge-population-camp-count]
    set health-level (health-level + ( knowledge-stock-per-camp / knowledge-population-camp-count))
end

to update-stock
  if population-camp-count > 0
  [
    let average-needs-per-day-per-camp (mean [needs-per-day] of people with [camp-belong = myself])
    if-else stock >= (average-needs-per-day-per-camp * population-camp-count)
    [
      set stock max list 0 ( stock - (average-needs-per-day-per-camp * population-camp-count) )
    ]
    [
      set stock max list 0 (stock -  ((stock / population-camp-count) * population-camp-count) )
    ]
  ]

end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;monitor and humorgs;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


to check-monitoring-cycle

  if-else monitor-time-cycle = [monitor-time-cycle] of other monitors
  [
    set still-monitor? True
    change-monitor-cycle
  ]
  [
    set still-monitor? False
   ; monitor-procedure ;given there is similar cycle plan, hence procedure is started after coordination finishes
  ]
end

to change-monitor-cycle
  set monitor-time-cycle random-poisson average-monitor-time-cycle
  check-monitoring-cycle
end

to monitor-procedure
    update-population-monitor
    update-monitor-cost
    update-monitor-needs
    ;report-monitor
end


to update-population-monitor
  if (tick-counter mod monitor-time-cycle = 0)
  [
    ask camps
    [
      set population-camp-count (count people with [camp-belong = myself])
    ]
   ; set population-monitor (sum [population-camp-count] of camps)  ; later must calculate how many people in each camp
  ]

end

to update-monitor-cost
  if (tick-counter mod monitor-time-cycle = 0 ) ;or (tick-counter = 0)
  [
    set area-division-monitor? True

    if-else monitor-area-coordination-given-similar-actual-monitoring-cycle?
    [
      ;set area-division-monitor? True
      set total-monitor-cost total-monitor-cost + (monitor-cost / max list 1 (count monitors with [area-division-monitor? = True]) ) ;number-of-monitoring-organization)
    ]
    [
      set total-monitor-cost total-monitor-cost + (monitor-cost)
    ]

  ]
end

to update-monitor-needs
  if (tick-counter mod monitor-time-cycle = 0 ) ;or (tick-counter = 0)
  [
    ask camps
    [
      set needs-camp-count ( max list 0 (initial-camp-capacity - stock) ) ;; should be connected to number of population and NOT camp initial capacity
    ]

    if-else monitor-area-coordination-given-similar-actual-monitoring-cycle?
    [
      set area-division-monitor? True
      set needs-monitor (sum [needs-camp-count] of camps) / max list 1 (count monitors with [area-division-monitor? = True]) ; number-of-monitoring-organization
    ]
    [
      set needs-monitor (sum [needs-camp-count] of camps)
    ]
    update-needs-covered
  ]
end


to update-needs-covered
  ask humorgs
  [
    set needs-covered sum [needs-monitor] of monitors
    update-distribution
    ;set update-distribution-time? True
  ]

end


to update-distribution
;  set distribute-tick distribute-tick + 1
;  if distribute-tick = logistic-distribution-time
;  [
    set logistic-sent (fraction-logistic-sent-per-needs-covered * needs-covered) ;/ number-of-humorgs)
    set humorgs-cost-average logistic-distribution-cost-per-unit * logistic-sent
    ask camps
    [
      receive-logistic
    ]
    set total-humorgs-cost total-humorgs-cost + humorgs-cost-average
;    set distribute-tick 0
;    set update-distribution-time? False
;  ]

end


to receive-logistic
  let logistic-sent-humorgs mean [logistic-sent] of humorgs ; assuming if some day multiple humorgs are assigned in the model
  set stock stock + (logistic-sent-humorgs) ; in aggregated way, assuming distribution to all camps to be equal. can be improved

end

;;; Plot functions ;;;


to plot-results

  set-current-plot "people-per-camp"
  ask camps [
    create-temporary-plot-pen ( word who )
    set-plot-pen-color color
    plot count people with [camp-belong = myself]
  ]

  set-current-plot "stocks per camp"
  ask camps [
    create-temporary-plot-pen ( word who )
    set-plot-pen-color color
    plot stock
  ]

;  set-current-plot "average cost of humanitarian organizations"
;  ask humorgs [
;    create-temporary-plot-pen ( word who )
;    set-plot-pen-color color
;    plot total-humorgs-cost
;  ]

  set-current-plot "average cost of monitoring organizations"
  ask monitors [
    create-temporary-plot-pen ( word who )
    set-plot-pen-color color
    plot total-monitor-cost
  ]

  set-current-plot "logistic-sent-per-humorg"
  ask humorgs [
    create-temporary-plot-pen ( word who )
    set-plot-pen-color color
    plot logistic-sent
  ]


;  set-current-plot "needs-monitored"
;  ask monitors [ ;monitors
;    create-temporary-plot-pen ( word who )
;    set-plot-pen-color color
;    plot needs-monitor
;  ]
;
end

to update-stats

  set total-people (sum [population-camp-count] of camps ) ; 1000 is the aggregated multiplier in order to get the actual number of people, for visual simplification.
 ;set total-people population-monitor
  ;set fraction-death (1 - ( total-people / (initial-total-people + (min list limit-people-influx-rate-to-camps (people-influx-rate-per-event-tick * tick-counter-limit ) ) ) )) * 100
  set fraction-death (1 - ( total-people / initial-total-people )) * 100
  set total-monitor-cost-of-monitoring-organizations (sum [total-monitor-cost] of monitors)
  set total-humorgs-cost-of-humorgs (sum [total-humorgs-cost] of humorgs)
end
@#$#@#$#@
GRAPHICS-WINDOW
226
10
627
412
-1
-1
11.91
1
10
1
1
1
0
1
1
1
-16
16
-16
16
1
1
1
ticks
30.0

SLIDER
652
234
887
267
total-camps
total-camps
0
10
3.0
1
1
NIL
HORIZONTAL

SLIDER
653
274
888
307
initial-camp-capacity
initial-camp-capacity
1000
50000
10000.0
1000
1
NIL
HORIZONTAL

SLIDER
654
312
888
345
base-health
base-health
10
100
30.0
5
1
NIL
HORIZONTAL

SLIDER
1129
316
1331
349
base-death-threshold
base-death-threshold
0
30
5.0
1
1
NIL
HORIZONTAL

SLIDER
904
194
1140
227
monsoon-effect-slider
monsoon-effect-slider
0
200
83.0
1
1
NIL
HORIZONTAL

SLIDER
745
40
949
73
number-of-monitoring-organization
number-of-monitoring-organization
0
10
1.0
1
1
NIL
HORIZONTAL

SLIDER
1154
194
1326
227
average-monitor-cost
average-monitor-cost
0
2000
1000.0
100
1
NIL
HORIZONTAL

SLIDER
976
38
1154
71
average-monitor-time-cycle
average-monitor-time-cycle
1
100
10.0
1
1
NIL
HORIZONTAL

SLIDER
907
314
1105
347
logistic-distribution-cost-per-unit
logistic-distribution-cost-per-unit
0
20
10.0
1
1
NIL
HORIZONTAL

SLIDER
904
238
1139
271
deviation-logistic-distribution-time
deviation-logistic-distribution-time
0
2
0.0
0.1
1
NIL
HORIZONTAL

BUTTON
653
366
715
399
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
731
366
794
400
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
903
277
1139
310
fraction-logistic-sent-per-needs-covered
fraction-logistic-sent-per-needs-covered
0
1
0.4
0.1
1
NIL
HORIZONTAL

PLOT
5
14
205
164
people-per-camp
NIL
NIL
0.0
90.0
0.0
100.0
true
false
"" ""
PENS

PLOT
5
284
205
434
average cost of monitoring organizations
NIL
NIL
0.0
90.0
0.0
20000.0
true
false
"" ""
PENS

PLOT
224
416
480
536
stocks per camp
NIL
NIL
0.0
90.0
0.0
5000.0
true
false
"" ""
PENS

PLOT
500
416
779
536
logistic-sent-per-humorg
NIL
NIL
0.0
90.0
0.0
10000.0
true
false
"" ""
PENS

MONITOR
7
447
194
492
NIL
total-monitor-cost-of-monitoring-organizations
2
1
11

MONITOR
8
504
195
549
NIL
total-humorgs-cost-of-humorgs
2
1
11

SLIDER
654
194
886
227
average-people-per-camp
average-people-per-camp
0
100
33.0
1
1
NIL
HORIZONTAL

SWITCH
678
84
914
117
similar-plan-monitoring-cycle?
similar-plan-monitoring-cycle?
0
1
-1000

TEXTBOX
890
11
1040
29
Monitoring Cycle Plan\n
14
0.0
1

CHOOSER
929
78
1236
123
coordination-type-when-similar-monitoring-plan-ON
coordination-type-when-similar-monitoring-plan-ON
"area" "schedule"
0

SLIDER
1152
237
1331
270
deviation-needs-per-day
deviation-needs-per-day
0
10
1.0
0.1
1
NIL
HORIZONTAL

SLIDER
1152
277
1324
310
tick-counter-limit
tick-counter-limit
10
200
90.0
10
1
NIL
HORIZONTAL

MONITOR
35
171
175
216
total people in all camps
total-people
0
1
11

MONITOR
25
221
179
266
% death rate in all camps
fraction-death
2
1
11

TEXTBOX
902
168
1052
186
External variables\n
14
0.0
1

@#$#@#$#@
## WHAT IS IT?

This is a simulation model for Rohingya refugee camps condition in Cox's Bazar, Bangladesh. The main objective is to behaviorally simulate different monitoring time cycle implementation of humanitarian organization(s) assigned for the monitoring process. Currently, as of August 2018, IOM is the sole monitoring organization for Rohingya refugee camps in Cox's Bazar. Through exploratory data input, the monitoring mechanism under various monitoring conditions (including possibility of information sharing mechanism within different monitoring organizations) can be observed dynamically.

The time context is the periodic monsoon time in Bangladesh which potentially deteriorates the living condition in the camps (assumed as three months = 90 days = 90 ticks). The space context is the three neighboring camps (camp 14, 15, 16) which geographically are highly vulnerable to the cyclone effect.

All in all, it aims to provide preliminary insight on the effect of monitoring activities and plans of monitoring organizations to the associated monitoring cost and the dynamics of humanitarian aid distribution. 



## HOW IT WORKS

In short, there are three classifications of actors considered: refugees in the camps who have (potentially increasing) needs, monitoring organization(s) which monitors the requirement of the refugees and report the condition, and humanitarian organization(s) which act(s) upon the monitoring report and send required logistics to the camps.

As tick starts, the monsoon hits the camps in random manner; negatively affecting the population which eventually increases their needs over time. Depending on the monitoring time cycle, monitoring organizations will come to the camps and take report of the number of population and the associated humanitarian needs. The report is informed to the humanitarian organizations, which will then send the required logistics to the camps.

For more details, refer to the file Conceptualization Overview.pdf.


## HOW TO USE IT

Setup and Go. Setup sets the model up, Go runs the model until the determined tick-counter-limit.

The 'Monitoring Cycle Plan' part consists of interfaces which allow users to play with the monitoring implementation of the monitoring organization(s), which is the main focus of this model. Number-of-monitoring-organization indicates number of monitoring organizations involved in the process, average-monitor-time-cycle indicates the average time cycle of monitoring organization(s), similar-plan? indicates whether there is any form of coordination given there are multiple monitoring organizations involved, and finally coordination-type indicates the form of coordination to be simulated. Regarding the latter, 'area' means that suppose the time cycle of each monitoring organization is similar, they will assess different areas hence allocating resources more efficiently. 

'schedule' means that each monitoring organization will be forced to different monitoring time cycle hence no chance of conflicting monitoring time cycle, which otherwise can potentially create inefficient resource allocation. Under this condition, each monitoring organization will assess all areas.

Meanwhile, the interface sliders are quite self-explanatory. With respect to the monitoring-related insight, focus more on monsoon-effect-slider, which informs the general severity of the monsoon.


## THINGS TO NOTICE

Notice the Monitors and Plots at the interface tab. 

The performance indicators are:
-. People-per-camp, % death rate in all camps, and total people in all camps are population-related indicators which are self-explanatory. 
-. total and average cost of monitoring organizations
-. total cost of humanitarian organizations which moves linearly with amount of logistic sent

Meanwhile, stocks per camp and amount of logistic sent Plots simply informs the internal process within the camps and humanitarian organization, which can help making sense of the associated performance indicators.


## THINGS TO TRY

Try to run the model under current condition: given only one monitoring organization, lack of information flows occur over time which affects aid distribution to the camps. Under the severity of monsoon this creates large amount of casualties. This can be improved by: reducing average monitoring time cycle; or increase the number of monitoring organization given that their time cycles are varied, with the average value of time cycle determined initially.

Regarding the latter, please continue playing with the interface of Monitoring Cycle Plan. Similar-plan-monitoring-cycle indicates whether there is a coordination plan set given there are more than 1 monitoring organizations. Brief explanation of this is as follows:

If set as No, then all the monitoring organizations in the simulation will basically do their own thing individually; they will even assess the whole camp location and report it despite there is already another monitoring organization assessing the whole location at the same time. This affects efficiency of monitoring cost overall, which can be monitored at the interface page. 

If set as Yes, the monitoring plan has to be chosen: "Area" or "Schedule". "Area" means that under the recently elaborated condition, if there is conflicting time schedule then these monitoring organizations will split the monitoring area among them, hence reducing the cost required to cover the whole area otherwise. Roughly aligned to this option is the information sharing mechanism, in which the reporting to humanitarian organizations for distribution of logistics is based on information coordination of the involved monitoring organizations. Meanwhile, "Schedule" indicates that no possible time conflict will occur, therefore the organizations will basically coordinate on each of their monitoring time cycle at the beginning.

## EXTENDING THE MODEL

The overall work, including desk research and interview process for gaining model-based information, is only committed in one week. It is reasonable to have multiple points of improvement, also considering the plausibility to have this model generalized to other refugee camps vulnerable to natural phenomenon in other places and time. Most important ones are:

-. Current assumption is given no coordination, each monitoring organization will assess whole camp areas completely. This is based on initial, actual insight on IOM monitoring process in Cox's Bazar, Bangladesh. This might not be the case given possibly more chaotic, lack of coordination under different circumstances in which multiple monitoring organizations are involved in the game. Therefore, alignment with reality under this different case is required.

-. Humanitarian organization supplying logistics given the monitoring report is assumed to be infinite and will distribute logistic as soon as the monitoring report is received. This is modeled by having one humanitarian organization with infinite resources and no processing and throughput time (i.e. delay). In reality, there can be some processing and throughput time, also limitations in terms of logistic supply and cost which can be considered to provide more realistic insight. This is currently not done due to the focus of the problem, which is monitoring cycle. To gain insight on the efficiency of the whole logistic monitor and distribution process, acknowledging this limitation is essential.

-. Number of population does not grow positively; due to the found generally stabilizing number of people in the Cox's Bazar (refer to assessment report online), it is assumed that under short monsoon time no one will be interested to go from Rakhine to the camp area and no birth is considered. Also, no transfer of population within camps is currently taken into account. In reality, based on literature consulted, this can happen when monsoon effect in one camp area is more severe than the other; this can cause higher uncertainties in needs and population monitoring process. Hence, integrating these elements can be beneficial.

-. Currently, the values in the model are largely exploratory; due to lack of time and resources it is not possible yet to get actual values of the most model variables. Hence, this model should currently be seen as a tool to facilitate understanding and gain insight on the behavioral pattern and humanitarian support mechanism for the refugee camps, rather than numerical forecasting. Refer to "How to Use It" and "Things to Try" columns to play with the model.

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike (CC-BY-NC-SA) License. DOI: 10.4121/uuid:01ec8b10-8356-49ed-b329-66d5efb9fc90 

This model is driven by information on monitoring process by IOM Bangladesh, which as of July 2018 still acts as the single monitoring organization in Cox's Bazaar. Literature on IOM Needs and Population Monitoring assessment method, which is highly relevant to the study setup, can be assessed in: https://displacement.iom.int/reports/bangladesh-%E2%80%93-site-assessment-methodology-march-2018. Credits to Ashik from IOM Bangladesh for helping with field-specific knowledge, especially related to the monitoring process in Cox's Bazaar.

Please contact me at: riz.januar@gmail.com (Rizky) for questions and suggestions.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

building institution
false
0
Rectangle -7500403 true true 0 60 300 270
Rectangle -16777216 true false 130 196 168 256
Rectangle -16777216 false false 0 255 300 270
Polygon -7500403 true true 0 60 150 15 300 60
Polygon -16777216 false false 0 60 150 15 300 60
Circle -1 true false 135 26 30
Circle -16777216 false false 135 25 30
Rectangle -16777216 false false 0 60 300 75
Rectangle -16777216 false false 218 75 255 90
Rectangle -16777216 false false 218 240 255 255
Rectangle -16777216 false false 224 90 249 240
Rectangle -16777216 false false 45 75 82 90
Rectangle -16777216 false false 45 240 82 255
Rectangle -16777216 false false 51 90 76 240
Rectangle -16777216 false false 90 240 127 255
Rectangle -16777216 false false 90 75 127 90
Rectangle -16777216 false false 96 90 121 240
Rectangle -16777216 false false 179 90 204 240
Rectangle -16777216 false false 173 75 210 90
Rectangle -16777216 false false 173 240 210 255
Rectangle -16777216 false false 269 90 294 240
Rectangle -16777216 false false 263 75 300 90
Rectangle -16777216 false false 263 240 300 255
Rectangle -16777216 false false 0 240 37 255
Rectangle -16777216 false false 6 90 31 240
Rectangle -16777216 false false 0 75 37 90
Line -16777216 false 112 260 184 260
Line -16777216 false 105 265 196 265

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

campsite
false
0
Polygon -7500403 true true 150 11 30 221 270 221
Polygon -16777216 true false 151 90 92 221 212 221
Line -7500403 true 150 30 150 225

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

factory
false
0
Rectangle -7500403 true true 76 194 285 270
Rectangle -7500403 true true 36 95 59 231
Rectangle -16777216 true false 90 210 270 240
Line -7500403 true 90 195 90 255
Line -7500403 true 120 195 120 255
Line -7500403 true 150 195 150 240
Line -7500403 true 180 195 180 255
Line -7500403 true 210 210 210 240
Line -7500403 true 240 210 240 240
Line -7500403 true 90 225 270 225
Circle -1 true false 37 73 32
Circle -1 true false 55 38 54
Circle -1 true false 96 21 42
Circle -1 true false 105 40 32
Circle -1 true false 129 19 42
Rectangle -7500403 true true 14 228 78 270

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.0.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>count turtles</metric>
    <enumeratedValueSet variable="average-monitor-time-cycle">
      <value value="4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="base-death-threshold">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="people-per-camp">
      <value value="33"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-camp-capacity">
      <value value="19000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="coordination-type-when-similar-monitoring-plan-ON">
      <value value="&quot;area&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="base-health">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-monitoring-organization">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-humorgs">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="base-needs-people-per-day">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fraction-logistic-sent-per-needs-covered">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="total-camps">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="monsoon-effect-slider">
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="monitor-duration-report">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="logistic-distribution-time">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="similar-plan-monitoring-cycle?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-monitor-cost">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="deviation-logistic-distribution-time">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="logistic-distribution-cost-per-unit">
      <value value="10"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
